durationtools.rational_to_equal_or_lesser_binary_rational
=========================================================

.. autofunction:: abjad.tools.durationtools.rational_to_equal_or_lesser_binary_rational.rational_to_equal_or_lesser_binary_rational
